package com.game.business.service;

import java.util.List;
import com.game.business.domain.LiveLive;
import com.baomidou.mybatisplus.extension.service.IService;

/**
 * 直播管理Service接口
 *
 * @author game
 * @date 2024-08-30
 */
public interface ILiveLiveService extends IService<LiveLive> {
    /**
     * 查询直播管理
     *
     * @param id 直播管理主键
     * @return 直播管理
     */
    public LiveLive selectLiveLiveById(Long id);

    /**
     * 查询直播管理
     *
     * @param userId
     * @return 直播管理
     */
    public LiveLive selectLiveLiveByUserId(Long userId);

    /**
     * 查询直播管理列表
     *
     * @param liveLive 直播管理
     * @return 直播管理集合
     */
    public List<LiveLive> selectLiveLiveList(LiveLive liveLive);

    /**
     * 新增直播管理
     *
     * @param liveLive 直播管理
     * @return 结果
     */
    public int insertLiveLive(LiveLive liveLive);

    /**
     * 修改直播管理
     *
     * @param liveLive 直播管理
     * @return 结果
     */
    public int updateLiveLive(LiveLive liveLive);

    /**
     * 批量删除直播管理
     *
     * @param ids 需要删除的直播管理主键集合
     * @return 结果
     */
    public int deleteLiveLiveByIds(Long[] ids);

    /**
     * 删除直播管理信息
     *
     * @param id 直播管理主键
     * @return 结果
     */
    public int deleteLiveLiveById(Long id);
}